<?php

namespace Drupal\meta_conversion_api\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Admin form for Meta Conversion API settings.
 */
class MetaConversionAPISettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'meta_conversion_api_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'meta_conversion_api.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormTitle() {
    return 'Meta Conversion API Settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('meta_conversion_api.settings');

    $form['meta_conversion_api'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Meta Conversion API Settings'),
    ];

    $form['meta_conversion_api']['meta_conversion_api_access_token'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Your Meta Conversion API Access Token'),
      '#description' => $this->t('You can generate this at @meta
        <ul>
          <li>Select the appropriate App under <em>Facebook App</em></li>
          <li>Then from <em>User or Page</em> select your listed page from <em>Page Access Tokens</em></li>
        </ul>
        ', ['@meta' => 'https://developers.facebook.com/tools/explorer/']),
      '#default_value' => $config->get('meta_conversion_api_access_token'),
      '#size' => 60,
      '#maxlength' => 255,
      '#required' => TRUE,
    ];

    $form['meta_conversion_api']['meta_conversion_api_pixel_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Your Meta Conversion API Pixel ID'),
      '#description' => $this->t('This is available at @meta', ['@meta' => 'https://business.facebook.com/overview/']),
      '#default_value' => $config->get('meta_conversion_api_pixel_id'),
      '#size' => 60,
      '#maxlength' => 255,
      '#required' => TRUE,
    ];

    $form['meta_conversion_api']['meta_conversion_api_test_event_code'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Your Meta Conversion API Test Event Code'),
      '#description' => $this->t('This is available at @meta in the form "TEST1234"', ['@meta' => 'https://business.facebook.com/events_manager2']),
      '#default_value' => $config->get('meta_conversion_api_test_event_code'),
      '#size' => 60,
      '#maxlength' => 255,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('meta_conversion_api.settings')
      ->set('meta_conversion_api_access_token', $form_state->getValue('meta_conversion_api_access_token'))
      ->set('meta_conversion_api_pixel_id', $form_state->getValue('meta_conversion_api_pixel_id'))
      ->set('meta_conversion_api_test_event_code', $form_state->getValue('meta_conversion_api_test_event_code'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
